@@ -12,10 +12,8 @@ use warnings;
 
 =head1 DESCRIPTION
 
-The Attribute base class is consumed by classes with attribute
-relationships like L<Interchange6::Schema::Result::User>,
-L<Interchange6::Schema::Result::Navigation>
-and L<Interchange6::Schema::Result::Product>.
+This Base class in intended to be added to classes that require attributes
+examples of these classes include User, Navigation and Product.
 
 =over 4
 
@@ -42,7 +40,7 @@ keys.  In general follow the example classes listed in description.
 
 Add attribute.
 
-    $base->add_attribute('hair_color', 'blond');
+$base->add_attribute('hair_color', 'blond');
 
 Where 'hair_color' is Attribute and 'blond' is AttributeValue
 
@@ -56,10 +54,10 @@ sub add_attribute {
     my ($attribute, $attribute_value) = $self->find_or_create_attribute($attr, $attr_value);
 
     # create base_attribute object
-    my $base_attribute = $self->find_or_create_related(lc($base) . '_attributes',
+    my $base_attribute = $self->find_or_create_related($base . 'Attribute',
                                                        {attributes_id => $attribute->id});
     # create base_attribute_value
-    $base_attribute->create_related(lc($base) . '_attribute_values',
+    $base_attribute->create_related($base . 'AttributeValue',
                                     {attribute_values_id => $attribute_value->id});
 
     return $self;
@@ -69,7 +67,7 @@ sub add_attribute {
 
 Update base attribute value
 
-    $base->update_attribute('hair_color', 'brown');
+$base->update_attribute('hair_color', 'brown');
 
 =cut
 
@@ -90,7 +88,7 @@ sub update_attribute_value {
 
 Delete $base attribute
 
-    $base->delete_attribute('hair_color', 'purple');
+$base->delete_attribute('hair_color', 'purple');
 
 =cut
 
@@ -111,27 +109,19 @@ sub delete_attribute {
 
 =head2 search_attributes
 
-Returns attributes resultset for a $base object
+Returns attributes for a $base object
 
-    $rs = $base->search_attributes;
-
-You can pass conditions and attributes to the search like for
-any L<DBIx::Class::ResultSet>, e.g.:
-
-    $rs = $base->search_attributes(
-        undef, { order_by => 'priority desc' });
+my $attr_rs = shop_product->find('WBA0001')->search_attributes;
 
 =cut
 
 sub search_attributes {
-    my ($self, $condition, $search_atts) = @_;
-
+    my ($self) = @_;
     my $base = $self->result_source->source_name;
 
-    my $base_attributes = $self->search_related(lc($base) . '_attributes');
+    my $base_attributes = $self->search_related($base . 'Attribute');
 
-    my $attributes = $base_attributes->search_related('attribute',
-                                                  $condition, $search_atts);
+    my $attributes = $base_attributes->search_related('Attribute');
 
     return $attributes;
 }
@@ -140,9 +130,9 @@ sub search_attributes {
 
 Finds the attribute value for the current object or a defined object value.
 If $object is passed the entire attribute_value object will be returned. $args can
-accept both scalar and hash inputs.
+accept both scaler and hash inputs.
 
-    $base->find_attribute_value({name => $attr_name, priority => $attr_priority}, {object => 1});
+$base->find_attribute_value({name => $attr_name, priority => $attr_priority}, {object => 1});
 
 =cut
 
@@ -151,34 +141,34 @@ sub find_attribute_value {
     my $base = $self->result_source->source_name;
     my $lc_base = lc($base);
 
+    my %attr = ref($args) eq 'HASH' ? %{$args} : (name => $args);
+
     # attribute must be set
     unless ($args) {
-       die "find_attribute_value input requires at least a valid attribute value";
+       die "find_attribute_value input requires atleast a valid attribute value";
     };
 
-    my %attr = ref($args) eq 'HASH' ? %{$args} : (name => $args);
-
     my $attribute = $self->result_source->schema->resultset('Attribute')->find( \%attr );
 
     unless ($attribute) {
-        return undef;
+        return;
     }
 
     # find records
-    my $base_attribute = $self->find_related($lc_base . '_attributes',
+    my $base_attribute = $self->find_related($base . 'Attribute',
                                             {attributes_id => $attribute->id});
 
     unless ($base_attribute) {
-        return undef;
+        return;
     }
 
-    my $base_attribute_value = $base_attribute->find_related($lc_base .'_attribute_values',
+    my $base_attribute_value = $base_attribute->find_related($base .'AttributeValue',
                                             {$lc_base . '_attributes_id' => $base_attribute->id});
     unless ($base_attribute_value) {
-        return undef;
+        return;
     }
 
-    my $attribute_value = $base_attribute_value->find_related('attribute_value',
+    my $attribute_value = $base_attribute_value->find_related('AttributeValue',
                                             {lc($base) .'_attribute_values_id' => $base_attribute_value->id});
     if ($object) {
         return $attribute_value;
@@ -188,53 +178,6 @@ sub find_attribute_value {
     }
 };
 
-=head2 search_attribute_values
-
-=over 4
-
-=item Arguments: L<$cond|DBIx::Class::SQLMaker> | undef, L<\%attrs|DBIx::Class::ResultSet/ATTRIBUTES> | undef, L<\%av_attrs|DBIx::Class::ResultSet/ATTRIBUTES>
-
-Where $cond and %attrs are passed to the Attribute search and %av_attrs is passed to the AttributeValue search.
-
-=item Return Value: Array (or arrayref in scalar context) of attributes and values for for the $base object input.
-
-=back
-
-    my $product = $schema->resultset('Product')->find({ sku = '123' });
-    my $av = $product->search_attribute_values(
-        undef, { order_by => 'priority' }, { order_by => 'priority' });
-
-=cut
-
-sub search_attribute_values {
-    my ($self, $condition, $search_atts, $av_search_atts) = @_;
-    my $base = $self->result_source->source_name; 
-    my (%base_data, %attr_values, @data);
-
-    my $base_attributes = $self->search_related(lc($base) . '_attributes');
-
-    my $attributes_rs = $base_attributes->search_related('attribute',
-                                                  $condition, $search_atts);
-
-    while (my $attribute = $attributes_rs->next) {
-        my @values;
-        my $attribute_value_rs = $attribute->search_related('attribute_values',
-            undef, $av_search_atts);
-        while (my $attribute_value = $attribute_value_rs->next) {
-
-            # get key value pairs
-            my %attr_values = $attribute_value->get_columns;
-            push( @values, { %attr_values });
-        }
-        my %base_data = $attribute->get_columns;
-
-        # populate values
-        $base_data{attribute_values} = \@values;
-        push( @data, { %base_data });
-    }
-    return wantarray ? @data : \@data;
-};
-
 =head2 find_or_create_attribute
 
 Find or create attribute and attribute_value.
@@ -242,22 +185,22 @@ Find or create attribute and attribute_value.
 =cut
 
 sub find_or_create_attribute {
-    my ( $self, $attr, $value ) = @_;
+    my ($self, @args) = @_;
 
-    unless ( defined($attr) && defined($value) ) {
+    # check if $args[0] is a HASH if not set as name
+    my %attr = ref($args[0]) eq 'HASH' ? %{$args[0]} : (name => $args[0]);
+
+    unless (defined($args[0] && $args[1])) {
         die "Both attribute and attribute value are required for find_or_create_attribute";
     }
 
-    # check if $attr is a HASH if not set as name
-    my %attr = ref($attr) eq 'HASH' ? %{$attr} : (name => $attr);
-
-    # check if $value is a HASH if not set as value
-    my %attr_value = ref($value) eq 'HASH' ? %{$value} : (value => $value);
+    # check if $args[1] is a HASH if not set as value
+    my %attr_value = ref($args[1]) eq 'HASH' ? %{$args[1]} : (value => $args[1]);
 
     my $attribute = $self->result_source->schema->resultset('Attribute')->find_or_create( %attr );
 
     # create attribute_values
-    my $attribute_value = $attribute->find_or_create_related('attribute_values', \%attr_value );
+    my $attribute_value = $attribute->find_or_create_related('AttributeValue', \%attr_value );
 
     return ($attribute, $attribute_value);
 };
@@ -270,21 +213,16 @@ From a $base->attribute input $base_attribute, $base_attribute_value is returned
 
 sub find_base_attribute_value {
     my ($self, $attribute, $base) = @_;
-
-    unless($base) {
-        die "Missing base name for find_base_attribute_value";
-    }
+    my $lc_base = lc($base);
 
     unless($attribute) {
         die "Missing attribute object for find_base_attribute_value";
     }
 
-    my $lc_base = lc($base);
-
-    my $base_attribute = $self->find_related($lc_base . '_attributes',
+    my $base_attribute = $self->find_related($base . 'Attribute',
                                             {attributes_id => $attribute->id});
 
-    my $base_attribute_value = $base_attribute->find_related($lc_base . '_attribute_values',
+    my $base_attribute_value = $base_attribute->find_related($base . 'AttributeValue',
                                             {$lc_base . '_attributes_id' => $base_attribute->id});
 
     return ($base_attribute, $base_attribute_value);
